<?php
class Spam_Interceptor {
    private $blocked_phrases;
    public function __construct() { $this->blocked_phrases = get_option( 'spam_interceptor_targets', '' ); }
    public function run() {
        if ( is_admin() ) $this->define_admin_hooks();
        else $this->define_public_hooks();
    }
    private function define_admin_hooks() {
        add_action( 'admin_menu', array( $this, 'add_plugin_menu' ) );
        add_action( 'admin_init', array( $this, 'register_settings' ) );
    }
    public function add_plugin_menu() {
        add_menu_page( esc_html__( 'Spam Interceptor', 'spam-interceptor' ), 'Spam Interceptor', 'manage_options', 'spam-interceptor', array( $this, 'display_settings_page' ), 'dashicons-email' );
    }
    public function register_settings() {
        register_setting( 'spam_interceptor_settings', 'spam_interceptor_targets', 'sanitize_textarea_field' );
        register_setting( 'spam_interceptor_settings', 'spam_interceptor_additional_settings', 'sanitize_additional_settings' );
    }
    public function sanitize_additional_settings( $input ) {
        $output = array();
        foreach ( $input as $key => $value ) {
            $output[ sanitize_key( $key ) ] = sanitize_text_field( $value );
        }
        return $output;
    }
    public function display_settings_page() {
        if ( ! current_user_can( 'manage_options' ) ) wp_die( esc_html__( 'You do not have sufficient permissions to access this page.', 'spam-interceptor' ) );
        include plugin_dir_path( __FILE__ ) . '../admin/views/settings-page.php';
    }
    private function define_public_hooks() {
        add_filter( 'gform_validation', array( $this, 'validate_gravity_forms' ) );
    }
    public function validate_gravity_forms( $validation_result ) {
        $nonce = isset( $_POST['spam_interceptor_nonce'] ) ? sanitize_text_field( wp_unslash( $_POST['spam_interceptor_nonce'] ) ) : '';
        if ( ! wp_verify_nonce( $nonce, 'spam_interceptor_nonce_action' ) ) {
            return $validation_result;
        }
        $form = $validation_result['form'];
        $blocked_phrases = explode( PHP_EOL, $this->blocked_phrases );
        foreach ( $form['fields'] as &$field ) {
            if ( isset( $_POST['input_' . $field->id] ) ) {
                $value = sanitize_text_field( wp_unslash( $_POST['input_' . $field->id] ) );
                foreach ( $blocked_phrases as $phrase ) {
                    if ( ! empty( $phrase ) && stripos( $value, trim( $phrase ) ) !== false ) {
                        $field->failed_validation = true;
                        $field->validation_message = esc_html__( 'Your submission contains blocked content.', 'spam-interceptor' );
                        $validation_result['is_valid'] = false;
                    }
                }
            }
        }
        $validation_result['form'] = $form;
        return $validation_result;
    }
}
